<img src="docs/logo.png" width="322" alt="django-scarface" />
-----------

Send push notifications to mobile devices using Amazon SNS

[![Documentation Status](https://readthedocs.org/projects/django-scarface/badge/?version=latest)](https://readthedocs.org/projects/django-scarface/?badge=latest)

Documentation
-----------
http://django-scarface.readthedocs.org/

Project Home
------------
https://github.com/dreipol/django-scarface

PyPi
------------
https://pypi.python.org/pypi/django-scarface


Trivia
------------
django-scarface is named after the track ‘Push it to the Limit’ featured in the movie Scarface (1983).

![Scarface the movie (1983)](docs/scarface-movie.png "Scarface the movie (1983)")
